#!/bin/bash
#
# Please, don`n modify the value of this variable, it have been generated autmatically to tagged container image
KIUWAN_TAG_DOCKER_IMAGE='master.201908011118.227'


# This script must be executed with an user of sudo group or with root user
#
# ----
# Main
# ----
# Check custom settings
if [ ! -e ./settings.custom ]; then
 clear
 echo "[i] ./settings.custom does not exist, please"
 echo "[i] copy settings.tpl as settings.custom, cp settings.tpl settings.custom, then custommize settings.custom and execute this script again"
 exit 1
fi
source ./settings.custom

# Check license
if [ ! -e ./license/license.zip -o ! -e ./license/configq1.zip ]; then
  clear
  echo "[i] You must have a license.zip and configq1.zip file to build the container"
  exit 1
fi

# Check java release 8u202
if [ ! -e ./jdk-8u202-linux-x64.tar.gz ]; then
  clear
  echo "[i] You must have the jdk-8u202-linux-x64.tar.gz file downloaded in the current directory. You can download it from here:"
  echo "[i] https://www.oracle.com/technetwork/java/javase/downloads/java-archive-javase8-2177648.html"
  exit 1
fi

# Check kiuwan user and group

ARE_THERE_U=`grep -r ^${KIUWAN_USER}.* /etc/passwd | awk -F ":" '{print $1}'`
ARE_THERE_G=`grep -r ^${KIUWAN_GROUP}.* /etc/group | awk -F ":" '{print $1}'`

if [ "${ARE_THERE_G}" = "" -o "${ARE_THERE_U}" = "" ]; then
 echo "[i] the group ${KIUWAN_GROUP} or user ${KIUWAN_USER} or both does not exist, you must create them first"
 exit 1
fi

N_UID=`grep -r ^${KIUWAN_USER}.* /etc/passwd | awk -F ":" '{print $3}'`
N_GID=`grep -r ^${KIUWAN_GROUP}.* /etc/group | awk -F ":" '{print $3}'`
#
KIUWAN_USER_UID=${N_UID}
KIUWAN_GROUP_GID=${N_GID}

CMD1="docker build --no-cache \\n"
sed -i 's|^ARG USE_PROXY=.*|ARG USE_PROXY='"${USE_PROXY}"'|' ./Dockerfile																		 
case ${USE_PROXY} in
 'true')
  sed -i 's|^ARG HOST_PROXY=.*|ARG HOST_PROXY='"${HOST_PROXY}"'|' ./Dockerfile
  sed -i 's|^ARG PORT_PROXY=.*|ARG PORT_PROXY='"${PORT_PROXY}"'|' ./Dockerfile
# check if anonymous proxy  
  if [ "${USER_PROXY}" = "" ]; then
   PROXY_SET="${HOST_PROXY}:${PORT_PROXY}"
  else
   PROXY_SET="${USER_PROXY}:${PWD_PROXY}@${HOST_PROXY}:${PORT_PROXY}"
  fi
  sed -i 's|^ARG USER_PROXY=.*|ARG USER_PROXY='"${USER_PROXY}"'|' ./Dockerfile
  sed -i 's|^ARG PWD_PROXY=.*|ARG PWD_PROXY='"${PWD_PROXY}"'|' ./Dockerfile
  sed -i 's|^ARG http_proxy=.*|ARG http_proxy=http://'"${PROXY_SET}"'|' ./Dockerfile
  sed -i 's|^ARG https_proxy=.*|ARG https_proxy=http://'"${PROXY_SET}"'|' ./Dockerfile
  sed -i 's|^ARG no_proxy=.*|ARG no_proxy='\'"${NO_PROXY}","${KIUWAN_HOST}"\''|' ./Dockerfile  
  ;;
 'false')
  sed -i 's|^ARG HOST_PROXY=.*|ARG HOST_PROXY=|' ./Dockerfile
  sed -i 's|^ARG PORT_PROXY=.*|ARG PORT_PROXY=|' ./Dockerfile
  sed -i 's|^ARG USER_PROXY=.*|ARG USER_PROXY=|' ./Dockerfile
  sed -i 's|^ARG PWD_PROXY=.*|ARG PWD_PROXY=|' ./Dockerfile  
  sed -i 's|^ARG http_proxy=.*|ARG http_proxy=|' ./Dockerfile
  sed -i 's|^ARG https_proxy=.*|ARG https_proxy=|' ./Dockerfile
  sed -i 's|^ARG no_proxy=.*|ARG no_proxy=|' ./Dockerfile  
  ;;
 *)
  echo "You must decide to use a proxy or not, USE_PROXY must be true or false"
  exit 1
  ;;
esac

# about connection settings
sed -i 's|^\s*ARG\s*KIUWAN_WEBSERVER_PROTOCOL\s*=.*|ARG KIUWAN_WEBSERVER_PROTOCOL='"${KIUWAN_WEBSERVER_PROTOCOL}"'|' ./Dockerfile
sed -i 's|^\s*ARG\s*KIUWAN_WEBSERVER_HOST\s*=.*|ARG KIUWAN_WEBSERVER_HOST='"${KIUWAN_WEBSERVER_HOST}"'|' ./Dockerfile
sed -i 's|^\s*ARG\s*KIUWAN_WEBSERVER_PORT\s*=.*|ARG KIUWAN_WEBSERVER_PORT='"${KIUWAN_WEBSERVER_PORT}"'|' ./Dockerfile
sed -i 's|^\s*ARG\s*KIUWAN_PORT\s*=.*|ARG KIUWAN_PORT='"${KIUWAN_PORT}"'|' ./Dockerfile
sed -i 's|^\s*ARG\s*KIUWAN_APPSERVER_AJP_PORT\s*=.*|ARG KIUWAN_APPSERVER_AJP_PORT='"${KIUWAN_APPSERVER_AJP_PORT}"'|' ./Dockerfile

CMD2="--build-arg KIUWAN_VOL=${KIUWAN_VOL} \\n
  --build-arg KIUWAN_USER=${KIUWAN_USER} \\n
  --build-arg KIUWAN_GROUP=${KIUWAN_GROUP} \\n
  --build-arg KIUWAN_USER_UID=${KIUWAN_USER_UID} \\n
  --build-arg KIUWAN_GROUP_GID=${KIUWAN_GROUP_GID} \\n
  --build-arg KIUWAN_MYSQL_USER=${KIUWAN_MYSQL_USER} \\n
  --build-arg KIUWAN_MYSQL_PWD=${KIUWAN_MYSQL_PWD} \\n
  --build-arg SSH_ROOT_PWD=${SSH_ROOT_PWD} \\n
  --build-arg MYSQL_ROOT_PWD=${MYSQL_ROOT_PWD} \\n
  --build-arg INNODB_BUFFER_POOL_SIZE=${INNODB_BUFFER_POOL_SIZE} \\n
  --build-arg APPS_JVMMAXMEMORY=${APPS_JVMMAXMEMORY} \\n
  --build-arg KIUWAN_REDIS_MAXMEMORY=${KIUWAN_REDIS_MAXMEMORY} \\n
  --build-arg KIUWAN_EMAIL_ADMIN_ACCOUNT=${KIUWAN_EMAIL_ADMIN_ACCOUNT} \\n
  --build-arg KIUWAN_EMAIL_USER_ACCOUNT=${KIUWAN_EMAIL_USER_ACCOUNT} \\n
  --build-arg KIUWAN_SMTP_USER_ACCOUNT=${KIUWAN_SMTP_USER_ACCOUNT} \\n
  --build-arg KIUWAN_SMTP_USER_PASSWORD=${KIUWAN_SMTP_USER_PASSWORD} \\n
  --build-arg KIUWAN_SMTP_HOST=${KIUWAN_SMTP_HOST} \\n
  --build-arg KIUWAN_SMTP_PORT=${KIUWAN_SMTP_PORT} \\n
  --build-arg MONGODB_START=${MONGODB_START} \\n
  -t ${KIUWAN_DOCKER_IMAGE}:${KIUWAN_TAG_DOCKER_IMAGE} ."

CMD=`echo -e "${CMD1} ${CMD2}"`
$CMD

if [ "$?" = "0" ]; then
  # Create run_init_kop.sh   
  if [ -e run_init_kop.sh ]; then
    rm -f run_init_kop.sh
  fi 
  echo "[i] Kiuwan image for kop built successfully, starting initialization"
  echo "[i] Creating script with docker command to initialize the Kiuwan container"
  echo "[i] You can reset the Kiuwan container by executing this script: run_init_kop.sh"

# Please, do not indented this code portion 
# Init EOF
# Note: It is important that there is no spaces or any other character at the end of the line
cat << EOF > ./run_init_kop.sh
#!/bin/bash
#
KIUWAN_TAG_DOCKER_IMAGE=${KIUWAN_TAG_DOCKER_IMAGE}
source ./settings.custom
echo "[i] All data on persistent volume will be erased"
read -p "Are you sure? (Y|y|N|n)" -n 1 -r
if [[ ! \$REPLY =~ ^[Yy]$ ]]; then
  exit 1
fi
echo ""
docker run --rm --name \${KIUWAN_HOST} \\
-h \${KIUWAN_HOST} \\
-v \${DIR_PERSISTENT_VOLUME}/\${KIUWAN_HOST}:\${KIUWAN_VOL} \\
-e KIUWAN_FIRST_TIME=Y \\
-it \${KIUWAN_DOCKER_IMAGE}:\${KIUWAN_TAG_DOCKER_IMAGE}
EOF
# End EOF

chmod +x run_init_kop.sh 

# Check run_kop.sh.rollback
if [ -e ./run_kop.sh.rollback ]; then
 rm -f ./run_kop.sh.rollback 
fi
# Create run_kop.sh 
if [ -e run_kop.sh ]; then
  rm -f run_kop.sh
fi
# Please, do not indented this code portion 
# Init EOF
# Note: It is important that there is no spaces or any other character at the end of the line
cat << EOF > ./run_kop.sh
#!/bin/bash
#
KIUWAN_TAG_DOCKER_IMAGE=${KIUWAN_TAG_DOCKER_IMAGE}
source ./settings.custom
docker run --rm --name \${KIUWAN_HOST} \\
-h \${KIUWAN_HOST} \\
-v \${DIR_PERSISTENT_VOLUME}/\${KIUWAN_HOST}:\${KIUWAN_VOL} \\
-p \${EXTERNAL_PORT_TO_MAP_MYSQL_INTERNAL_PORT}:3306 \\
-p \${EXTERNAL_PORT_TO_MAP_SSH_PORT}:22 \\
-p \${EXTERNAL_PORT_TO_MAP_APPSERVER_PORT}:\${KIUWAN_PORT} \\
-p \${EXTERNAL_PORT_TO_MAP_APPSERVER_AJP_PORT}:\${KIUWAN_APPSERVER_AJP_PORT} \\
-e START_AND_RUN=Y \\
-d \${KIUWAN_DOCKER_IMAGE}:\${KIUWAN_TAG_DOCKER_IMAGE}
sleep 10
docker exec -it \${KIUWAN_HOST} /bin/sh -c "/usr/bin/tail -n -1 -f \${KIUWAN_VOL}/logs/wildfly/wildfly_out.log | { /bin/sed '/started in/ q' && /usr/bin/killall tail ;}"
EOF
# End EOF
  chmod +x run_kop.sh
  clear
  ./run_init_kop.sh
  if [ "$?" = "0" ]; then
   clear  
   echo "[i] Kiuwan docker image ${KIUWAN_DOCKER_IMAGE}:${KIUWAN_TAG_DOCKER_IMAGE} built and initialized sucessfully"
   echo "[i] You can run this container by executing the following script:"   
   echo "[i] ./run_kop.sh"
  fi 
else
  echo "[i] Error building the image"
fi
