# -------------------------------------------------------------
# settings.tpl
#
# This file is a template to customize your kiuwan installation
# Edit these variables or keep their original values to build a
# Kiuwan on premise default installation
# -------------------------------------------------------------

# --------------
# Proxy settings
# --------------
# If there is a proxy server, Docker will use these variables.
# Only http and https proxies are supported. Proxy SOCKS is not supported.

# Whether to use a proxy server or not
# false: Don't use proxy to build and run container
# true: Use proxy to build the container and inside the running container
USE_PROXY=false

# Proxy configuration
HOST_PROXY=host_proxy
PORT_PROXY=3128
USER_PROXY=user_proxy
PWD_PROXY=pwd_proxy

# Comma separated list of hosts to ignore when connecting through proxy
# There is no need to put here KIUWAN_HOST
NO_PROXY=localhost,127.*

# -------------------------------------
# URLs, Ports and Connections to Kiuwan
# -------------------------------------
# You may access Kiuwan through a front-end server. Please read carefully the
# online documentation if you plan to access Kiuwan on premise this way.
# If you don't need a front-end server note that:
# KIUWAN_WEBSERVER_HOST and KIUWAN_HOST must point to the same host and 
# KIUWAN_WEBSERVER_PORT and KIUWAN_PORT must be the same port

# If no front-end server will be used and you want to access Kiuwan on premise
# through https, please refer to the online documentation for details
# on how to configure this properties

# Kiuwan front-end server protocol
KIUWAN_WEBSERVER_PROTOCOL=http

# Kiuwan front-end server host name
KIUWAN_WEBSERVER_HOST=kop.mydomain.com

# Kiuwan front-end server port (may be empty if a front-end server will be used)
KIUWAN_WEBSERVER_PORT=7080

# If KIUWAN_WEBSERVER_PROTOCOL is https you must change HTTPS to ON
HTTPS=OFF

# Kiuwan back-end server host name
KIUWAN_HOST=kop.mydomain.com

# Kiuwan back-end server port
KIUWAN_PORT=7080

# Kiuwan back-end server AJP port (used to connect front-end server to back-end server)
# This port must be set even if no front-end server will be used
KIUWAN_APPSERVER_AJP_PORT=7009

# Docker image name
KIUWAN_DOCKER_IMAGE=kiuwan_image

# Path to physical directory where the persisten volume will be created (without final slash)
DIR_PERSISTENT_VOLUME=/Datavol

# ---------------------------------
# Ports exposed by kiuwan container
# ---------------------------------
EXTERNAL_PORT_TO_MAP_MYSQL_INTERNAL_PORT=3306
EXTERNAL_PORT_TO_MAP_SSH_PORT=2222
EXTERNAL_PORT_TO_MAP_APPSERVER_PORT=7080
EXTERNAL_PORT_TO_MAP_APPSERVER_AJP_PORT=7009

# ----------------------------------------
# Variables to use inside kiuwan container
# ----------------------------------------

# Internal dir in container to map to DIR_PERSISTENT_VOLUME
KIUWAN_VOL=/kiuwan_vol

# Starting services
# true: Start mongodb (license with architecture included)
# false: Don't start mongodb (license without architecture) 
MONGODB_START=false

# -------------------
# Users and passwords
# -------------------

# User and group to start services
KIUWAN_USER=kiuwan
KIUWAN_GROUP=kiuwan

# Mysql user and password that kiuwan will use to connect to mysql
KIUWAN_MYSQL_USER=kiuwan
KIUWAN_MYSQL_PWD=kiuwan

# Root password to connect through ssh 
SSH_ROOT_PWD=password

# Root password to connect to mysql
MYSQL_ROOT_PWD=root

# ---------------
# Memory settings
# ---------------
# Mysql
INNODB_BUFFER_POOL_SIZE=2G

# Wildfly
APPS_JVMMAXMEMORY=3G

# Redis
KIUWAN_REDIS_MAXMEMORY=2gb

# --------------
# Mails settings
# --------------
KIUWAN_EMAIL_ADMIN_ACCOUNT=dummy.kop@gmail.com
KIUWAN_EMAIL_USER_ACCOUNT=dummy.kop@gmail.com
KIUWAN_SMTP_USER_ACCOUNT=dummy.kop@gmail.com
KIUWAN_SMTP_USER_PASSWORD=dummykop.pass
KIUWAN_SMTP_HOST=smtp.gmail.com
KIUWAN_SMTP_PORT=587

# End settings
