#!/bin/bash

if [ "$1" = "" -o "$1" != "./updateClientsLauncher.sh" ]; then
  clear	
  echo "This scrips can not invocated by itself, it must be called by ${settings_dir}/updates/bin/updateClientsLauncher.sh"
  exit
fi
source ${settings_dir}/settings.custom

#
# Check custom settings
if [ ! -e ${settings_dir}/settings.custom ]; then
 clear
 echo "[i] ${settings_dir}/settings.custom does not exist, please"
 echo "[i] this file is necesary to update kiuwan on premises"
 exit 1
fi

JAVA_VERSION=`grep "ARG JAVA_VERSION=" ${settings_dir}/Dockerfile | awk -F "=" '{print $2}'`
KIUWAN_DOWNLOAD_URL=`grep "KIUWAN_DOWNLOAD_URL=" ${settings_dir}/Dockerfile | awk -F "=" '{print $2}'`
KIUWAN_DOWNLOAD_URL=`echo $KIUWAN_DOWNLOAD_URL | sed 's|\"||g'`
DIR_RELEASE="${KIUWAN_VOL}/release"
#
NOW=`date +%Y-%m-%d_%Hh%m%Ss`

function version { echo "$@" | awk -F "." '{ printf("%03d%03d%03d%03d\n", $1,$2,$3,$4); }'; }
CURRENT_KIUWAN_VERSION=`docker exec -it ${KIUWAN_HOST} cat ${DIR_RELEASE}/current.version`	
# Kiuwan compatible version
EXISTS_COMPATIBILITY_FILE=`docker exec -it ${KIUWAN_HOST} [ -f compatibility.version ] && echo "Found" || echo "Not found"`
if [ "${EXISTS_COMPATIBILITY_FILE}" = "Found" ]; then
	docker exec -it ${KIUWAN_HOST} mv compatibility.version ${DIR_RELEASE}/compatibility.version.${NOW}
fi
docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/compatibility.version
CLIENTS_COMPATIBILITY_VERSION=`docker exec -it ${KIUWAN_HOST} cat compatibility.version`
if [ "$(version "$CLIENTS_COMPATIBILITY_VERSION")" -gt "$(version "$CURRENT_KIUWAN_VERSION")" ]; then
	echo "[i] Current Kiuwan version is not compatible with the latest available clients"
	echo "[i] Current Kiuwan version is ${CURRENT_KIUWAN_VERSION}"
	echo "[i] Minimum Kiuwan version needed to upgrade clients is ${CLIENTS_COMPATIBILITY_VERSION}"	
else 
	# Update clients
	# Update K4Ds
	# Eclipse
	echo "- Update K4D Eclipse ------------------"
	OLD_K4D_E_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat $KIUWAN_VOL/welcome-content/pub/updatesite/k4d_E.version`
	docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/k4d_E.version
	KIUWAN_K4D_E_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat k4d_E.version`
	if [[ ${KIUWAN_K4D_E_DISTRIBUTION} == *"No such file"* ]]; then
		echo "[w] Error downloading K4D Eclipse, contact with kiuwan support"
	else 
		if [ "${OLD_K4D_E_DISTRIBUTION}" = "${KIUWAN_K4D_E_DISTRIBUTION}" ]; then
			echo "[i] K4D Eclipse distribution is up to date"
			docker exec -it ${KIUWAN_HOST} rm k4d_E.version
		else 
			docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/KiuwanForDevelopers.Eclipse_${KIUWAN_K4D_E_DISTRIBUTION}.zip
			docker exec -it ${KIUWAN_HOST} rm -rf /root/kiuwan/tmp/archived/updatesite /root/kiuwan/tmp/welcome-content/pub/updatesite
			docker exec -it ${KIUWAN_HOST} unzip -o KiuwanForDevelopers.Eclipse_${KIUWAN_K4D_E_DISTRIBUTION}.zip -d /root/kiuwan/tmp/welcome-content/pub
			docker exec -it ${KIUWAN_HOST} mv $KIUWAN_VOL/welcome-content/pub/updatesite /root/kiuwan/tmp/archived/.
			docker exec -it ${KIUWAN_HOST} cp -rf /root/kiuwan/tmp/welcome-content/pub/updatesite $KIUWAN_VOL/welcome-content/pub/.
			docker exec -it ${KIUWAN_HOST} cp -rf /root/kiuwan/tmp/archived/updatesite/engines $KIUWAN_VOL/welcome-content/pub/updatesite/.
			docker exec -it ${KIUWAN_HOST} cp -f k4d_E.version $KIUWAN_VOL/welcome-content/pub/updatesite
			docker exec -it ${KIUWAN_HOST} rm KiuwanForDevelopers.Eclipse_${KIUWAN_K4D_E_DISTRIBUTION}.zip
		fi
	fi
	docker exec -it ${KIUWAN_HOST} rm -f k4d_E.version
	echo ""
	# Visual Studio
	echo "- Update K4D Visual Studio ------------------"
	OLD_K4D_VS_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat $KIUWAN_VOL/welcome-content/pub/vsgallery/k4d_VS.version`	
	docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/k4d_VS.version
	KIUWAN_K4D_VS_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat k4d_VS.version`
	if [[ ${KIUWAN_K4D_VS_DISTRIBUTION} == *"No such file"* ]]; then
		echo "[w] Error downloading K4D Visual Studio, contact with kiuwan support"
	else 
		if [ "${OLD_K4D_VS_DISTRIBUTION}" = "${KIUWAN_K4D_VS_DISTRIBUTION}" ]; then
			echo "[i] K4D Visual Studio distribution is up to date"
			docker exec -it ${KIUWAN_HOST} rm k4d_VS.version
		else
			docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/KiuwanForDevelopers.VisualStudio_${KIUWAN_K4D_VS_DISTRIBUTION}.zip
			docker exec -it ${KIUWAN_HOST} rm -rf /root/kiuwan/tmp/archived/vsgallery /root/kiuwan/tmp/welcome-content/pub/vsgallery
			docker exec -it ${KIUWAN_HOST} unzip -o KiuwanForDevelopers.VisualStudio_${KIUWAN_K4D_VS_DISTRIBUTION}.zip -d /root/kiuwan/tmp/welcome-content/pub
			docker exec -it ${KIUWAN_HOST} mv $KIUWAN_VOL/welcome-content/pub/vsgallery /root/kiuwan/tmp/archived/.
			docker exec -it ${KIUWAN_HOST} cp -rf /root/kiuwan/tmp/welcome-content/pub/vsgallery $KIUWAN_VOL/welcome-content/pub/.
			docker exec -it ${KIUWAN_HOST} cp -f k4d_VS.version $KIUWAN_VOL/welcome-content/pub/vsgallery
			docker exec -it ${KIUWAN_HOST} rm KiuwanForDevelopers.VisualStudio_${KIUWAN_K4D_VS_DISTRIBUTION}.zip
		fi
	fi
	docker exec -it ${KIUWAN_HOST} rm -f k4d_VS.version
	echo ""
	# JetBrains
	echo "- Update K4D JetBrains ------------------"
	OLD_K4D_JB_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat $KIUWAN_VOL/welcome-content/pub/jetbrains/k4d_JB.version`
	docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/k4d_JB.version
	KIUWAN_K4D_JB_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat k4d_JB.version`
	if [[ ${KIUWAN_K4D_JB_DISTRIBUTION} == *"No such file"* ]]; then
		echo "[w] Error downloading K4D JetBrains, contact with kiuwan support"
	else 
		if [ "${OLD_K4D_JB_DISTRIBUTION}" = "${KIUWAN_K4D_JB_DISTRIBUTION}" ]; then
			echo "[i] K4D JetBrains distribution is up to date"
			docker exec -it ${KIUWAN_HOST} rm k4d_JB.version
		else
			docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/KiuwanForDevelopers.JetBrains_${KIUWAN_K4D_JB_DISTRIBUTION}.zip
			docker exec -it ${KIUWAN_HOST} rm -rf /root/kiuwan/tmp/archived/jetbrains /root/kiuwan/tmp/welcome-content/pub/jetbrains
			docker exec -it ${KIUWAN_HOST} unzip -o KiuwanForDevelopers.JetBrains_${KIUWAN_K4D_JB_DISTRIBUTION}.zip -d /root/kiuwan/tmp/welcome-content/pub
			docker exec -it ${KIUWAN_HOST} mv $KIUWAN_VOL/welcome-content/pub/jetbrains /root/kiuwan/tmp/archived/.
			docker exec -it ${KIUWAN_HOST} cp -rf /root/kiuwan/tmp/welcome-content/pub/jetbrains $KIUWAN_VOL/welcome-content/pub/.
			docker exec -it ${KIUWAN_HOST} cp -f k4d_JB.version $KIUWAN_VOL/welcome-content/pub/jetbrains
			docker exec -it ${KIUWAN_HOST} rm KiuwanForDevelopers.JetBrains_${KIUWAN_K4D_JB_DISTRIBUTION}.zip
		fi
	fi
	docker exec -it ${KIUWAN_HOST} rm -f k4d_JB.version
	echo ""
	# VisualStudioCode
	echo "- Update K4D VSCode ------------------"
	OLD_K4D_VSCODE_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat $KIUWAN_VOL/welcome-content/pub/vscode/k4d_VSCode.version`
	docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/k4d_VSCode.version
	KIUWAN_K4D_VSCODE_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat k4d_VSCode.version`
	if [[ ${KIUWAN_K4D_VSCODE_DISTRIBUTION} == *"No such file"* ]]; then
		echo "[w] Error downloading K4D VisualStudioCode, contact with kiuwan support"
	else 
		if [ "${OLD_K4D_VSCODE_DISTRIBUTION}" = "${KIUWAN_K4D_VSCODE_DISTRIBUTION}" ]; then
			echo "[i] K4D VisualStudioCode distribution is up to date"
			docker exec -it ${KIUWAN_HOST} rm k4d_VSCode.version
		else
			docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/KiuwanForDevelopers.VSCode_${KIUWAN_K4D_VSCODE_DISTRIBUTION}.zip
			docker exec -it ${KIUWAN_HOST} rm -rf /root/kiuwan/tmp/archived/vscode /root/kiuwan/tmp/welcome-content/pub/vscode
			docker exec -it ${KIUWAN_HOST} unzip -o KiuwanForDevelopers.VSCode_${KIUWAN_K4D_VSCODE_DISTRIBUTION}.zip -d /root/kiuwan/tmp/welcome-content/pub
			docker exec -it ${KIUWAN_HOST} mv $KIUWAN_VOL/welcome-content/pub/vscode /root/kiuwan/tmp/archived/.
			docker exec -it ${KIUWAN_HOST} cp -rf /root/kiuwan/tmp/welcome-content/pub/vscode $KIUWAN_VOL/welcome-content/pub/.
			docker exec -it ${KIUWAN_HOST} cp -f k4d_VSCode.version $KIUWAN_VOL/welcome-content/pub/vscode
			docker exec -it ${KIUWAN_HOST} rm KiuwanForDevelopers.VSCode_${KIUWAN_K4D_VSCODE_DISTRIBUTION}.zip
		fi
	fi
	docker exec -it ${KIUWAN_HOST} rm -f k4d_VSCode.version
	echo ""
	# Update KLA
	echo "- Update KLA -----------------------"
	OLD_KLA_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat $KIUWAN_VOL/welcome-content/pub/analyzer/agent.version`
	docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/agent.version
	KIUWAN_KLA_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat agent.version`
	if [[ ${KIUWAN_KLA_DISTRIBUTION} == *"No such file"* ]]; then
		echo "[w] Error downloading kiuwan agent, contact with kiuwan support"
	else 
		if [ "${OLD_KLA_DISTRIBUTION}" = "${KIUWAN_KLA_DISTRIBUTION}" ]; then
			echo "[i] KLA distribution is up to date"
			docker exec -it ${KIUWAN_HOST} rm agent.version
		else
			docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/KiuwanLocalAnalyzer_${KIUWAN_KLA_DISTRIBUTION}.zip
			docker exec -it ${KIUWAN_HOST} mv /root/kiuwan/tmp/welcome-content/pub/analyzer/KiuwanLocalAnalyzer.zip /root/kiuwan/tmp/welcome-content/pub/analyzer/KiuwanLocalAnalyzer.zip.${NOW}
			docker exec -it ${KIUWAN_HOST} unzip -o KiuwanLocalAnalyzer_${KIUWAN_KLA_DISTRIBUTION}.zip -d /root/kiuwan/tmp/welcome-content/pub
			docker exec -it ${KIUWAN_HOST} cp /root/kiuwan/tmp/welcome-content/pub/analyzer/KiuwanLocalAnalyzer.zip .
			docker exec -it ${KIUWAN_HOST} unzip KiuwanLocalAnalyzer.zip
			# Unzip current KiuwanLocalAnalyzer.zip on /tmp/workdir
			docker exec -it ${KIUWAN_HOST} mkdir /tmp/workdir
			docker exec -it ${KIUWAN_HOST} unzip $KIUWAN_VOL/welcome-content/pub/analyzer/KiuwanLocalAnalyzer.zip -d /tmp/workdir
			# Extract settings configurated to overwrite them on new agent.properties
			URL_PRE_CONFIGURATED=`docker exec -it ${KIUWAN_HOST} grep -e "^url=.*" /tmp/workdir/KiuwanLocalAnalyzer/conf/agent.properties | awk -F "=" '{ print $2 }'` 
			REST_SERVICES_PRE_CONFIGURATED=`docker exec -it ${KIUWAN_HOST} grep -e "^rest.services.url=.*" /tmp/workdir/KiuwanLocalAnalyzer/conf/agent.properties | awk -F "=" '{ print $2 }'` 			
			DOWNLOAD_URL_PRE_CONFIGURATED=`docker exec -it ${KIUWAN_HOST} grep -e "^download.url=.*" /tmp/workdir/KiuwanLocalAnalyzer/conf/agent.properties | awk -F "=" '{ print $2 }'` 						
			docker exec -it ${KIUWAN_HOST} rm -rf /tmp/workdir          
			docker exec -it ${KIUWAN_HOST} sed -i 's|^url=.*|url='"${URL_PRE_CONFIGURATED}"'|g' KiuwanLocalAnalyzer/conf/agent.properties
			docker exec -it ${KIUWAN_HOST} sed -i 's|^rest.services.url=.*|rest.services.url='"${REST_SERVICES_PRE_CONFIGURATED}"'|g' KiuwanLocalAnalyzer/conf/agent.properties
			docker exec -it ${KIUWAN_HOST} sed -i 's|^download.url=.*|download.url='"${DOWNLOAD_URL_PRE_CONFIGURATED}"'|g' KiuwanLocalAnalyzer/conf/agent.properties
			docker exec -it ${KIUWAN_HOST} /opt/jdk1.${JAVA_VERSION}/bin/jar -uf KiuwanLocalAnalyzer.zip KiuwanLocalAnalyzer/conf/agent.properties
			docker exec -it ${KIUWAN_HOST} cp KiuwanLocalAnalyzer.zip /root/kiuwan/tmp/welcome-content/pub/analyzer/.			
			# Copy updated KLA to pub directory
			docker exec -it ${KIUWAN_HOST} cp -r /root/kiuwan/tmp/welcome-content/pub/analyzer/KiuwanLocalAnalyzer.zip $KIUWAN_VOL/welcome-content/pub/analyzer/.
			docker exec -it ${KIUWAN_HOST} cp -rf /root/kiuwan/tmp/welcome-content/pub/analyzer/agent.version $KIUWAN_VOL/welcome-content/pub/analyzer/.
			# Update agent.version
			docker exec -it ${KIUWAN_HOST} mv -f agent.version /root/kiuwan/tmp/welcome-content/pub/analyzer/.
			# Remove temp files
			docker exec -it ${KIUWAN_HOST} rm -rf KiuwanLocalAnalyzer KiuwanLocalAnalyzer.zip KiuwanLocalAnalyzer_${KIUWAN_KLA_DISTRIBUTION}.zip
		fi
	fi
	docker exec -it ${KIUWAN_HOST} rm -f agent.version
	echo ""
	# Update Engine
	echo "- Update Engine ----------------------"
	OLD_ENGINE_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat $KIUWAN_VOL/welcome-content/pub/analyzer/engine.version`	
	docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/engine.version
	KIUWAN_ENGINE_DISTRIBUTION=`docker exec -it ${KIUWAN_HOST} cat engine.version`
	if [[ ${KIUWAN_ENGINE_DISTRIBUTION} == *"No such file"* ]]; then
		echo "[w] Error downloading kiuwan engine, contact with kiuwan support"
	else 
		if [ "${OLD_ENGINE_DISTRIBUTION}" = "${KIUWAN_ENGINE_DISTRIBUTION}" ]; then
			echo "[i] Engine distribution is up to date"	
		else 		
			docker exec -it ${KIUWAN_HOST} wget --no-check-certificate ${KIUWAN_DOWNLOAD_URL}/KiuwanEngine_${KIUWAN_ENGINE_DISTRIBUTION}.zip
			docker exec -it ${KIUWAN_HOST} mkdir /KiuwanEngine
			docker exec -it ${KIUWAN_HOST} unzip -o KiuwanEngine_${KIUWAN_ENGINE_DISTRIBUTION}.zip -d /KiuwanEngine
			docker exec -it ${KIUWAN_HOST} cp /KiuwanEngine/analyzer/engine_${KIUWAN_ENGINE_DISTRIBUTION}.zip /root/kiuwan/tmp/welcome-content/pub/analyzer/.			
			docker exec -it ${KIUWAN_HOST} mkdir -p /root/kiuwan/tmp/welcome-content/pub/updatesite/engines
			docker exec -it ${KIUWAN_HOST} cp -rf /KiuwanEngine/updatesite/engines/${KIUWAN_ENGINE_DISTRIBUTION} /root/kiuwan/tmp/welcome-content/pub/updatesite/engines/.
			# Update engine.version
			docker exec -it ${KIUWAN_HOST} mv -f engine.version /root/kiuwan/tmp/welcome-content/pub/analyzer/.
			# Copy updated Engine to pub directory
			docker exec -it ${KIUWAN_HOST} cp -r /root/kiuwan/tmp/welcome-content/pub/analyzer/engine_${KIUWAN_ENGINE_DISTRIBUTION}.zip $KIUWAN_VOL/welcome-content/pub/analyzer/.
			docker exec -it ${KIUWAN_HOST} cp -rf /root/kiuwan/tmp/welcome-content/pub/analyzer/engine.version $KIUWAN_VOL/welcome-content/pub/analyzer/.
			docker exec -it ${KIUWAN_HOST} cp -r /root/kiuwan/tmp/welcome-content/pub/updatesite/engines/${KIUWAN_ENGINE_DISTRIBUTION} $KIUWAN_VOL/welcome-content/pub/updatesite/engines/.
			# Copy definitions and upgrade QMM.	
			docker exec -it ${KIUWAN_HOST} /bin/sh -c "mkdir -p $KIUWAN_VOL/definitions/$KIUWAN_ENGINE_DISTRIBUTION && cp -p /KiuwanEngine/definitions_*.zip $KIUWAN_VOL/definitions/$KIUWAN_ENGINE_DISTRIBUTION/."
			docker exec -it ${KIUWAN_HOST} /bin/sh -c "/opt/apache-ant-*/bin/ant -buildfile $KIUWAN_VOL/release/installation/upgrade_qmm.xml -Dkiuwanvol.dir=$KIUWAN_VOL -Drelease.dir=$KIUWAN_VOL/release -Ddefinitions.dir=$KIUWAN_VOL/definitions/$KIUWAN_ENGINE_DISTRIBUTION"			
			# Remove temp files
			docker exec -it ${KIUWAN_HOST} rm -rf KiuwanEngine KiuwanEngine_${KIUWAN_ENGINE_DISTRIBUTION}.zip
		fi
	fi
	docker exec -it ${KIUWAN_HOST} rm -f engine.version
fi
